// File: CPP-Example.cpp
// Description: Spellchecker C++ example.
// Copyright: (C) 2006 EffectiveSoft Ltd. All Rights Reserved.
// Technical support: technical-support@effective-soft.com

#include <iostream>
#include <BaseInterface.h>

//define this macro before including SpellChecker.h
//if you don't have debug libs for spellchecker
#define SEM_SDK_NO_DEBUG_LIBS

#include <SpellChecker.h>

using std::cout;
using std::cerr;

using namespace NsSemSDK;

int main(int argc, char* argv[])
{

	IDestructible* pSpellCheckerDB = NULL;		//pointer to spellchecker database

	try
	{
		char szPath[] = "LDB";				//path to ldb
		char szTextResult[4][10] = {"skip", "correct", "incorrect", "bad"};
		const char szWord[] = "Computre";		//incorrect spelling of word "Computer"
		const char szLang[] = "ENGLISH";		//language
		ISpellCheck::ERes eResult;				//word check result
		int nCandidatesCount = 0;				//number of candidates

		// provide path to license file
		SetSpellCheckerLicensePath("ISDK_License.xml");
		// Load database that is required to create the instance of ISpellCheck
		IDestructible* pSpellCheckerDB = LoadSpellCheckerDB(szPath);
		// Create instance of ISpellCheck that will check spelling and returns corrected word candidates
		CInterfacePtr<ISpellCheck> pSpellChecker(CreateSpellChecker(pSpellCheckerDB));
		CInterfacePtr<ICandidateList> pCandidateList;		//list of candidates

		// Enable word checking in all available languages
		pSpellChecker->EnableAllLanguagesProcessing(true);
		//Check word using default language
		eResult = pSpellChecker->CheckWord(szWord, &pCandidateList);

		//Get number of candidates
		nCandidatesCount = pCandidateList->Size();

		//Print word and check result text
		cout << szWord << "\t" << szTextResult[eResult] << "\n";

		cout << "Candidate:\tWeight\n";
		//Get and print candidates
		for (int i = 0; i < nCandidatesCount; i++)
		{
			Weight_t chWeight = 0;	//weight of candidate
			const char* pszCandidate = pCandidateList->At(i, &chWeight);
			cout << pszCandidate << "\t" << (double)chWeight << "\n";
		}

		cout << "Word\t" << szWord << "\twas checked with\t" << pCandidateList->GetLanguage() << "\tlanguage\n";
		//Reset list of candidates
		pCandidateList.Reset();
		// Disable word checking in all available languages
		pSpellChecker->EnableAllLanguagesProcessing(false);
		// Check word witch specified language:
		eResult = pSpellChecker->CheckWord(szWord, &pCandidateList, szLang);

		//Get number of candidates
		nCandidatesCount = pCandidateList->Size();

		//Print word and check result text
		cout << szWord << "\t" << szTextResult[eResult] << "\n";

		cout << "Candidate:\tWeight\n";
		//Get and print candidates
		for (int i = 0; i < nCandidatesCount; i++)
		{
			Weight_t chWeight = 0;	//weight of candidate
			const char* pszCandidate = pCandidateList->At(i, &chWeight);
			cout << pszCandidate << "\t" << (double)chWeight << "\n";
		}

		//Reset list of candidates
		pCandidateList.Reset();

		//Get skip word rule
		int nSpellFilter = pSpellChecker->GetSpellFilter();
		//Change skip word rules
		pSpellChecker->SetSpellFilter(ISpellCheck::SKIP_WORD_UPPER_CASE | nSpellFilter);
		eResult = pSpellChecker->CheckWord(szWord, &pCandidateList);
		cout << szWord << "\t" << szTextResult[eResult] << "\n";

	}
	catch (const CSemBaseException& x)
	{
		// Handle exceptions.
		cerr << x.what();
	}

	if (pSpellCheckerDB != NULL)
		pSpellCheckerDB->Destroy();

	return 0;
}
